Resources
=========

This page lists resources related to GnuCash, and more specifically, to the use of Python for GnuCash.

GnuCash links
-------------

- The official GnuCash page : http://www.gnucash.org/
- The official python bindings : http://wiki.gnucash.org/wiki/Python_Bindings (wiki)
  and http://svn.gnucash.org/docs/head/python_bindings_page.html (svn)

Web resources
-------------
- List (XML) of currencies with their ISO code : http://www.currency-iso.org/dam/downloads/table_a1.xml
- Quandl (for exchange rates) : http://www.quandl.com
- Yahoo! query language : https://developer.yahoo.com/yql/console/

Blogs & discussions
-------------------

- blog with GnuCash/python links (not 100% correct): http://wideopenstudy.blogspot.be/search/label/GnuCash
- on timezone in GnuCash: http://do-the-right-things.blogspot.be/2013/11/caveats-in-using-gnucash-time-zone.html
- Google search on python in user mailing list: `python site:http://lists.gnucash.org/pipermail/gnucash-user" python <https://www.google.be/search?hl=en&as_q=python&as_epq=&as_oq=&as_eq=&as_nlo=&as_nhi=&lr=&cr=&as_qdr=all&as_sitesearch=http%3A%2F%2Flists.gnucash.org%2Fpipermail%2Fgnucash-user&as_occt=any&safe=images&tbs=&as_filetype=&as_rights=>`__
- Google search on python in devel mailing list: `python site:http://lists.gnucash.org/pipermail/gnucash-devel" python <https://www.google.be/search?hl=en&as_q=python&as_epq=&as_oq=&as_eq=&as_nlo=&as_nhi=&lr=&cr=&as_qdr=all&as_sitesearch=http%3A%2F%2Flists.gnucash.org%2Fpipermail%2Fgnucash-devel&as_occt=any&safe=images&tbs=&as_filetype=&as_rights=>`__

Github projects related to GnuCash
----------------------------------

.. toctree::
   :maxdepth: 1

   ./github_links.rst

Python links
------------

- cross compilation of python executable from Linux to Windows :
  http://milkator.wordpress.com/2014/07/19/windows-executable-from-python-developing-in-ubuntu/
- SQLAlchemy page: http://www.sqlalchemy.org/

Threads used during the course of development
---------------------------------------------

- sphinx error message:
  http://stackoverflow.com/questions/15249340/warning-document-isnt-included-in-any-toctree-for-included-file

Thanks
------

None of this could be possible without :

- the GnuCash project, its core team of developers and its active community of users
- python and its packages amongst which sqlalchemy
- github, readthedocs and travis-ci for managing code, docs and testing
